namespaceservice

package
v0.0.0-...-aa6ffdd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	NamespaceService_CreateNamespace_FullMethodName = "/conductor.api.namespace.v1.NamespaceService/CreateNamespace"
	NamespaceService_ListNamespace_FullMethodName   = "/conductor.api.namespace.v1.NamespaceService/ListNamespace"
)

Variables

var File_namespaceservice_v1_namespaceservice_proto protoreflect.FileDescriptor
var NamespaceService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "conductor.api.namespace.v1.NamespaceService",
	HandlerType: (*NamespaceServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateNamespace",
			Handler:    _NamespaceService_CreateNamespace_Handler,
		},
		{
			MethodName: "ListNamespace",
			Handler:    _NamespaceService_ListNamespace_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "namespaceservice/v1/namespaceservice.proto",
}

NamespaceService_ServiceDesc is the grpc.ServiceDesc for NamespaceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterNamespaceServiceServer

func RegisterNamespaceServiceServer(s grpc.ServiceRegistrar, srv NamespaceServiceServer)

Types

type CreateNamespaceRequest

type CreateNamespaceRequest struct {

	// 命名空间名称
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateNamespaceRequest) Descriptor deprecated

func (*CreateNamespaceRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateNamespaceRequest.ProtoReflect.Descriptor instead.

func (*CreateNamespaceRequest) GetName

func (x *CreateNamespaceRequest) GetName() string

func (*CreateNamespaceRequest) ProtoMessage

func (*CreateNamespaceRequest) ProtoMessage()

func (*CreateNamespaceRequest) ProtoReflect

func (x *CreateNamespaceRequest) ProtoReflect() protoreflect.Message

func (*CreateNamespaceRequest) Reset

func (x *CreateNamespaceRequest) Reset()

func (*CreateNamespaceRequest) String

func (x *CreateNamespaceRequest) String() string

type CreateNamespaceResponse

type CreateNamespaceResponse struct {
	Namespace *v1.Namespace `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateNamespaceResponse) Descriptor deprecated

func (*CreateNamespaceResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateNamespaceResponse.ProtoReflect.Descriptor instead.

func (*CreateNamespaceResponse) GetNamespace

func (x *CreateNamespaceResponse) GetNamespace() *v1.Namespace

func (*CreateNamespaceResponse) ProtoMessage

func (*CreateNamespaceResponse) ProtoMessage()

func (*CreateNamespaceResponse) ProtoReflect

func (x *CreateNamespaceResponse) ProtoReflect() protoreflect.Message

func (*CreateNamespaceResponse) Reset

func (x *CreateNamespaceResponse) Reset()

func (*CreateNamespaceResponse) String

func (x *CreateNamespaceResponse) String() string

type ListNamespaceRequest

type ListNamespaceRequest struct {

	// 页码,从 1 开始
	Page int32 `protobuf:"varint,1,opt,name=page,proto3" json:"page,omitempty"`
	// 每页数量
	Count int32 `protobuf:"varint,2,opt,name=count,proto3" json:"count,omitempty"`
	// contains filtered or unexported fields
}

func (*ListNamespaceRequest) Descriptor deprecated

func (*ListNamespaceRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListNamespaceRequest.ProtoReflect.Descriptor instead.

func (*ListNamespaceRequest) GetCount

func (x *ListNamespaceRequest) GetCount() int32

func (*ListNamespaceRequest) GetPage

func (x *ListNamespaceRequest) GetPage() int32

func (*ListNamespaceRequest) ProtoMessage

func (*ListNamespaceRequest) ProtoMessage()

func (*ListNamespaceRequest) ProtoReflect

func (x *ListNamespaceRequest) ProtoReflect() protoreflect.Message

func (*ListNamespaceRequest) Reset

func (x *ListNamespaceRequest) Reset()

func (*ListNamespaceRequest) String

func (x *ListNamespaceRequest) String() string

type ListNamespaceResponse

type ListNamespaceResponse struct {
	Namespaces []*v1.Namespace `protobuf:"bytes,1,rep,name=namespaces,proto3" json:"namespaces,omitempty"`
	// 总数
	Total int64 `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
	// contains filtered or unexported fields
}

func (*ListNamespaceResponse) Descriptor deprecated

func (*ListNamespaceResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListNamespaceResponse.ProtoReflect.Descriptor instead.

func (*ListNamespaceResponse) GetNamespaces

func (x *ListNamespaceResponse) GetNamespaces() []*v1.Namespace

func (*ListNamespaceResponse) GetTotal

func (x *ListNamespaceResponse) GetTotal() int64

func (*ListNamespaceResponse) ProtoMessage

func (*ListNamespaceResponse) ProtoMessage()

func (*ListNamespaceResponse) ProtoReflect

func (x *ListNamespaceResponse) ProtoReflect() protoreflect.Message

func (*ListNamespaceResponse) Reset

func (x *ListNamespaceResponse) Reset()

func (*ListNamespaceResponse) String

func (x *ListNamespaceResponse) String() string

type NamespaceServiceClient

type NamespaceServiceClient interface {
	// 创建命名空间
	CreateNamespace(ctx context.Context, in *CreateNamespaceRequest, opts ...grpc.CallOption) (*CreateNamespaceResponse, error)
	// 分页列出命名空间
	ListNamespace(ctx context.Context, in *ListNamespaceRequest, opts ...grpc.CallOption) (*ListNamespaceResponse, error)
}

NamespaceServiceClient is the client API for NamespaceService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type NamespaceServiceServer

type NamespaceServiceServer interface {
	// 创建命名空间
	CreateNamespace(context.Context, *CreateNamespaceRequest) (*CreateNamespaceResponse, error)
	// 分页列出命名空间
	ListNamespace(context.Context, *ListNamespaceRequest) (*ListNamespaceResponse, error)
	// contains filtered or unexported methods
}

NamespaceServiceServer is the server API for NamespaceService service. All implementations must embed UnimplementedNamespaceServiceServer for forward compatibility.

type UnimplementedNamespaceServiceServer

type UnimplementedNamespaceServiceServer struct{}

UnimplementedNamespaceServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedNamespaceServiceServer) CreateNamespace

func (UnimplementedNamespaceServiceServer) ListNamespace

type UnsafeNamespaceServiceServer

type UnsafeNamespaceServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeNamespaceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NamespaceServiceServer will result in compilation errors.

Jump to