Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCounterServiceServer(s grpc.ServiceRegistrar, srv CounterServiceServer)
- type AddRecordRequest
- func (*AddRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AddRecordRequest) GetBizCode() int32
- func (x *AddRecordRequest) GetOid() int64
- func (x *AddRecordRequest) GetUid() int64
- func (*AddRecordRequest) ProtoMessage()
- func (x *AddRecordRequest) ProtoReflect() protoreflect.Message
- func (x *AddRecordRequest) Reset()
- func (x *AddRecordRequest) String() string
- type AddRecordResponse
- type BatchCheckHasActDoDoRequest
- func (*BatchCheckHasActDoDoRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BatchCheckHasActDoDoRequest) GetBizCode() int32
- func (x *BatchCheckHasActDoDoRequest) GetParams() map[int64]*ObjectList
- func (*BatchCheckHasActDoDoRequest) ProtoMessage()
- func (x *BatchCheckHasActDoDoRequest) ProtoReflect() protoreflect.Message
- func (x *BatchCheckHasActDoDoRequest) Reset()
- func (x *BatchCheckHasActDoDoRequest) String() string
- type BatchCheckHasActDoResponse
- func (*BatchCheckHasActDoResponse) Descriptor() ([]byte, []int)deprecated
- func (x *BatchCheckHasActDoResponse) GetResults() map[int64]*BatchCheckHasActDoResponse_ItemList
- func (*BatchCheckHasActDoResponse) ProtoMessage()
- func (x *BatchCheckHasActDoResponse) ProtoReflect() protoreflect.Message
- func (x *BatchCheckHasActDoResponse) Reset()
- func (x *BatchCheckHasActDoResponse) String() string
- type BatchCheckHasActDoResponse_Item
- func (*BatchCheckHasActDoResponse_Item) Descriptor() ([]byte, []int)deprecated
- func (x *BatchCheckHasActDoResponse_Item) GetDo() bool
- func (x *BatchCheckHasActDoResponse_Item) GetOid() int64
- func (*BatchCheckHasActDoResponse_Item) ProtoMessage()
- func (x *BatchCheckHasActDoResponse_Item) ProtoReflect() protoreflect.Message
- func (x *BatchCheckHasActDoResponse_Item) Reset()
- func (x *BatchCheckHasActDoResponse_Item) String() string
- type BatchCheckHasActDoResponse_ItemList
- func (*BatchCheckHasActDoResponse_ItemList) Descriptor() ([]byte, []int)deprecated
- func (x *BatchCheckHasActDoResponse_ItemList) GetList() []*BatchCheckHasActDoResponse_Item
- func (*BatchCheckHasActDoResponse_ItemList) ProtoMessage()
- func (x *BatchCheckHasActDoResponse_ItemList) ProtoReflect() protoreflect.Message
- func (x *BatchCheckHasActDoResponse_ItemList) Reset()
- func (x *BatchCheckHasActDoResponse_ItemList) String() string
- type BatchGetRecordRequest
- func (*BatchGetRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BatchGetRecordRequest) GetBizCode() int32
- func (x *BatchGetRecordRequest) GetParams() map[int64]*ObjectList
- func (*BatchGetRecordRequest) ProtoMessage()
- func (x *BatchGetRecordRequest) ProtoReflect() protoreflect.Message
- func (x *BatchGetRecordRequest) Reset()
- func (x *BatchGetRecordRequest) String() string
- type BatchGetRecordResponse
- func (*BatchGetRecordResponse) Descriptor() ([]byte, []int)deprecated
- func (x *BatchGetRecordResponse) GetResults() map[int64]*RecordList
- func (*BatchGetRecordResponse) ProtoMessage()
- func (x *BatchGetRecordResponse) ProtoReflect() protoreflect.Message
- func (x *BatchGetRecordResponse) Reset()
- func (x *BatchGetRecordResponse) String() string
- type BatchGetSummaryRequest
- func (*BatchGetSummaryRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BatchGetSummaryRequest) GetRequests() []*GetSummaryRequest
- func (*BatchGetSummaryRequest) ProtoMessage()
- func (x *BatchGetSummaryRequest) ProtoReflect() protoreflect.Message
- func (x *BatchGetSummaryRequest) Reset()
- func (x *BatchGetSummaryRequest) String() string
- type BatchGetSummaryResponse
- func (*BatchGetSummaryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *BatchGetSummaryResponse) GetResponses() []*GetSummaryResponse
- func (*BatchGetSummaryResponse) ProtoMessage()
- func (x *BatchGetSummaryResponse) ProtoReflect() protoreflect.Message
- func (x *BatchGetSummaryResponse) Reset()
- func (x *BatchGetSummaryResponse) String() string
- type CancelRecordRequest
- func (*CancelRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CancelRecordRequest) GetBizCode() int32
- func (x *CancelRecordRequest) GetOid() int64
- func (x *CancelRecordRequest) GetUid() int64
- func (*CancelRecordRequest) ProtoMessage()
- func (x *CancelRecordRequest) ProtoReflect() protoreflect.Message
- func (x *CancelRecordRequest) Reset()
- func (x *CancelRecordRequest) String() string
- type CancelRecordResponse
- type CheckHasActDoRequest
- func (*CheckHasActDoRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CheckHasActDoRequest) GetBizCode() int32
- func (x *CheckHasActDoRequest) GetOid() int64
- func (x *CheckHasActDoRequest) GetUid() int64
- func (*CheckHasActDoRequest) ProtoMessage()
- func (x *CheckHasActDoRequest) ProtoReflect() protoreflect.Message
- func (x *CheckHasActDoRequest) Reset()
- func (x *CheckHasActDoRequest) String() string
- type CheckHasActDoResponse
- func (*CheckHasActDoResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CheckHasActDoResponse) GetDo() bool
- func (*CheckHasActDoResponse) ProtoMessage()
- func (x *CheckHasActDoResponse) ProtoReflect() protoreflect.Message
- func (x *CheckHasActDoResponse) Reset()
- func (x *CheckHasActDoResponse) String() string
- type CounterServiceClient
- type CounterServiceServer
- type DelRecordRequest
- func (*DelRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DelRecordRequest) GetBizCode() int32
- func (x *DelRecordRequest) GetOid() int64
- func (x *DelRecordRequest) GetUid() int64
- func (*DelRecordRequest) ProtoMessage()
- func (x *DelRecordRequest) ProtoReflect() protoreflect.Message
- func (x *DelRecordRequest) Reset()
- func (x *DelRecordRequest) String() string
- type DelRecordResponse
- type GetRecordRequest
- func (*GetRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetRecordRequest) GetBizCode() int32
- func (x *GetRecordRequest) GetOid() int64
- func (x *GetRecordRequest) GetUid() int64
- func (*GetRecordRequest) ProtoMessage()
- func (x *GetRecordRequest) ProtoReflect() protoreflect.Message
- func (x *GetRecordRequest) Reset()
- func (x *GetRecordRequest) String() string
- type GetRecordResponse
- type GetSummaryRequest
- func (*GetSummaryRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetSummaryRequest) GetBizCode() int32
- func (x *GetSummaryRequest) GetOid() int64
- func (*GetSummaryRequest) ProtoMessage()
- func (x *GetSummaryRequest) ProtoReflect() protoreflect.Message
- func (x *GetSummaryRequest) Reset()
- func (x *GetSummaryRequest) String() string
- type GetSummaryResponse
- func (*GetSummaryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetSummaryResponse) GetBizCode() int32
- func (x *GetSummaryResponse) GetCount() int64
- func (x *GetSummaryResponse) GetOid() int64
- func (*GetSummaryResponse) ProtoMessage()
- func (x *GetSummaryResponse) ProtoReflect() protoreflect.Message
- func (x *GetSummaryResponse) Reset()
- func (x *GetSummaryResponse) String() string
- type ObjectList
- type PageGetUserRecordRequest
- func (*PageGetUserRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PageGetUserRecordRequest) GetBizCode() int32
- func (x *PageGetUserRecordRequest) GetCount() int32
- func (x *PageGetUserRecordRequest) GetCursor() string
- func (x *PageGetUserRecordRequest) GetSortRule() SortRule
- func (x *PageGetUserRecordRequest) GetUid() int64
- func (*PageGetUserRecordRequest) ProtoMessage()
- func (x *PageGetUserRecordRequest) ProtoReflect() protoreflect.Message
- func (x *PageGetUserRecordRequest) Reset()
- func (x *PageGetUserRecordRequest) String() string
- type PageGetUserRecordResponse
- func (*PageGetUserRecordResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PageGetUserRecordResponse) GetHasNext() bool
- func (x *PageGetUserRecordResponse) GetItems() []*Record
- func (x *PageGetUserRecordResponse) GetNextCursor() string
- func (*PageGetUserRecordResponse) ProtoMessage()
- func (x *PageGetUserRecordResponse) ProtoReflect() protoreflect.Message
- func (x *PageGetUserRecordResponse) Reset()
- func (x *PageGetUserRecordResponse) String() string
- type Record
- func (*Record) Descriptor() ([]byte, []int)deprecated
- func (x *Record) GetAct() RecordAct
- func (x *Record) GetBizCode() int32
- func (x *Record) GetCtime() int64
- func (x *Record) GetMtime() int64
- func (x *Record) GetOid() int64
- func (x *Record) GetUid() int64
- func (*Record) ProtoMessage()
- func (x *Record) ProtoReflect() protoreflect.Message
- func (x *Record) Reset()
- func (x *Record) String() string
- type RecordAct
- type RecordList
- type SortRule
- type UnimplementedCounterServiceServer
- func (UnimplementedCounterServiceServer) AddRecord(context.Context, *AddRecordRequest) (*AddRecordResponse, error)
- func (UnimplementedCounterServiceServer) BatchCheckHasActDo(context.Context, *BatchCheckHasActDoDoRequest) (*BatchCheckHasActDoResponse, error)
- func (UnimplementedCounterServiceServer) BatchGetRecord(context.Context, *BatchGetRecordRequest) (*BatchGetRecordResponse, error)
- func (UnimplementedCounterServiceServer) BatchGetSummary(context.Context, *BatchGetSummaryRequest) (*BatchGetSummaryResponse, error)
- func (UnimplementedCounterServiceServer) CancelRecord(context.Context, *CancelRecordRequest) (*CancelRecordResponse, error)
- func (UnimplementedCounterServiceServer) CheckHasActDo(context.Context, *CheckHasActDoRequest) (*CheckHasActDoResponse, error)
- func (UnimplementedCounterServiceServer) GetRecord(context.Context, *GetRecordRequest) (*GetRecordResponse, error)
- func (UnimplementedCounterServiceServer) GetSummary(context.Context, *GetSummaryRequest) (*GetSummaryResponse, error)
- func (UnimplementedCounterServiceServer) PageGetUserRecord(context.Context, *PageGetUserRecordRequest) (*PageGetUserRecordResponse, error)
- type UnsafeCounterServiceServer
Constants ¶
const ( CounterService_AddRecord_FullMethodName = "/counter.api.v1.CounterService/AddRecord" CounterService_CancelRecord_FullMethodName = "/counter.api.v1.CounterService/CancelRecord" CounterService_GetRecord_FullMethodName = "/counter.api.v1.CounterService/GetRecord" CounterService_BatchGetRecord_FullMethodName = "/counter.api.v1.CounterService/BatchGetRecord" CounterService_GetSummary_FullMethodName = "/counter.api.v1.CounterService/GetSummary" CounterService_BatchGetSummary_FullMethodName = "/counter.api.v1.CounterService/BatchGetSummary" CounterService_PageGetUserRecord_FullMethodName = "/counter.api.v1.CounterService/PageGetUserRecord" CounterService_CheckHasActDo_FullMethodName = "/counter.api.v1.CounterService/CheckHasActDo" CounterService_BatchCheckHasActDo_FullMethodName = "/counter.api.v1.CounterService/BatchCheckHasActDo" )
Variables ¶
var ( SortRule_name = map[int32]string{ 0: "SORT_RULE_UNSPECIFIED", 1: "SORT_RULE_ASC", 2: "SORT_RULE_DESC", } SortRule_value = map[string]int32{ "SORT_RULE_UNSPECIFIED": 0, "SORT_RULE_ASC": 1, "SORT_RULE_DESC": 2, } )
Enum value maps for SortRule.
var ( RecordAct_name = map[int32]string{ 0: "RECORD_ACT_UNSPECIFIED", 1: "RECORD_ACT_ADD", 2: "RECORD_ACT_UNADD", } RecordAct_value = map[string]int32{ "RECORD_ACT_UNSPECIFIED": 0, "RECORD_ACT_ADD": 1, "RECORD_ACT_UNADD": 2, } )
Enum value maps for RecordAct.
var CounterService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "counter.api.v1.CounterService", HandlerType: (*CounterServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AddRecord", Handler: _CounterService_AddRecord_Handler, }, { MethodName: "CancelRecord", Handler: _CounterService_CancelRecord_Handler, }, { MethodName: "GetRecord", Handler: _CounterService_GetRecord_Handler, }, { MethodName: "BatchGetRecord", Handler: _CounterService_BatchGetRecord_Handler, }, { MethodName: "GetSummary", Handler: _CounterService_GetSummary_Handler, }, { MethodName: "BatchGetSummary", Handler: _CounterService_BatchGetSummary_Handler, }, { MethodName: "PageGetUserRecord", Handler: _CounterService_PageGetUserRecord_Handler, }, { MethodName: "CheckHasActDo", Handler: _CounterService_CheckHasActDo_Handler, }, { MethodName: "BatchCheckHasActDo", Handler: _CounterService_BatchCheckHasActDo_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "v1/counter.proto", }
CounterService_ServiceDesc is the grpc.ServiceDesc for CounterService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_v1_counter_proto protoreflect.FileDescriptor
Functions ¶
func RegisterCounterServiceServer ¶
func RegisterCounterServiceServer(s grpc.ServiceRegistrar, srv CounterServiceServer)
Types ¶
type AddRecordRequest ¶
type AddRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*AddRecordRequest) Descriptor
deprecated
func (*AddRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use AddRecordRequest.ProtoReflect.Descriptor instead.
func (*AddRecordRequest) GetBizCode ¶
func (x *AddRecordRequest) GetBizCode() int32
func (*AddRecordRequest) GetOid ¶
func (x *AddRecordRequest) GetOid() int64
func (*AddRecordRequest) GetUid ¶
func (x *AddRecordRequest) GetUid() int64
func (*AddRecordRequest) ProtoMessage ¶
func (*AddRecordRequest) ProtoMessage()
func (*AddRecordRequest) ProtoReflect ¶
func (x *AddRecordRequest) ProtoReflect() protoreflect.Message
func (*AddRecordRequest) Reset ¶
func (x *AddRecordRequest) Reset()
func (*AddRecordRequest) String ¶
func (x *AddRecordRequest) String() string
type AddRecordResponse ¶
type AddRecordResponse struct {
// contains filtered or unexported fields
}
func (*AddRecordResponse) Descriptor
deprecated
func (*AddRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use AddRecordResponse.ProtoReflect.Descriptor instead.
func (*AddRecordResponse) ProtoMessage ¶
func (*AddRecordResponse) ProtoMessage()
func (*AddRecordResponse) ProtoReflect ¶
func (x *AddRecordResponse) ProtoReflect() protoreflect.Message
func (*AddRecordResponse) Reset ¶
func (x *AddRecordResponse) Reset()
func (*AddRecordResponse) String ¶
func (x *AddRecordResponse) String() string
type BatchCheckHasActDoDoRequest ¶
type BatchCheckHasActDoDoRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Params map[int64]*ObjectList `` /* 154-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BatchCheckHasActDoDoRequest) Descriptor
deprecated
func (*BatchCheckHasActDoDoRequest) Descriptor() ([]byte, []int)
Deprecated: Use BatchCheckHasActDoDoRequest.ProtoReflect.Descriptor instead.
func (*BatchCheckHasActDoDoRequest) GetBizCode ¶
func (x *BatchCheckHasActDoDoRequest) GetBizCode() int32
func (*BatchCheckHasActDoDoRequest) GetParams ¶
func (x *BatchCheckHasActDoDoRequest) GetParams() map[int64]*ObjectList
func (*BatchCheckHasActDoDoRequest) ProtoMessage ¶
func (*BatchCheckHasActDoDoRequest) ProtoMessage()
func (*BatchCheckHasActDoDoRequest) ProtoReflect ¶
func (x *BatchCheckHasActDoDoRequest) ProtoReflect() protoreflect.Message
func (*BatchCheckHasActDoDoRequest) Reset ¶
func (x *BatchCheckHasActDoDoRequest) Reset()
func (*BatchCheckHasActDoDoRequest) String ¶
func (x *BatchCheckHasActDoDoRequest) String() string
type BatchCheckHasActDoResponse ¶
type BatchCheckHasActDoResponse struct {
Results map[int64]*BatchCheckHasActDoResponse_ItemList `` /* 156-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BatchCheckHasActDoResponse) Descriptor
deprecated
func (*BatchCheckHasActDoResponse) Descriptor() ([]byte, []int)
Deprecated: Use BatchCheckHasActDoResponse.ProtoReflect.Descriptor instead.
func (*BatchCheckHasActDoResponse) GetResults ¶
func (x *BatchCheckHasActDoResponse) GetResults() map[int64]*BatchCheckHasActDoResponse_ItemList
func (*BatchCheckHasActDoResponse) ProtoMessage ¶
func (*BatchCheckHasActDoResponse) ProtoMessage()
func (*BatchCheckHasActDoResponse) ProtoReflect ¶
func (x *BatchCheckHasActDoResponse) ProtoReflect() protoreflect.Message
func (*BatchCheckHasActDoResponse) Reset ¶
func (x *BatchCheckHasActDoResponse) Reset()
func (*BatchCheckHasActDoResponse) String ¶
func (x *BatchCheckHasActDoResponse) String() string
type BatchCheckHasActDoResponse_Item ¶
type BatchCheckHasActDoResponse_Item struct {
Do bool `protobuf:"varint,1,opt,name=do,proto3" json:"do,omitempty"`
Oid int64 `protobuf:"varint,2,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*BatchCheckHasActDoResponse_Item) Descriptor
deprecated
func (*BatchCheckHasActDoResponse_Item) Descriptor() ([]byte, []int)
Deprecated: Use BatchCheckHasActDoResponse_Item.ProtoReflect.Descriptor instead.
func (*BatchCheckHasActDoResponse_Item) GetDo ¶
func (x *BatchCheckHasActDoResponse_Item) GetDo() bool
func (*BatchCheckHasActDoResponse_Item) GetOid ¶
func (x *BatchCheckHasActDoResponse_Item) GetOid() int64
func (*BatchCheckHasActDoResponse_Item) ProtoMessage ¶
func (*BatchCheckHasActDoResponse_Item) ProtoMessage()
func (*BatchCheckHasActDoResponse_Item) ProtoReflect ¶
func (x *BatchCheckHasActDoResponse_Item) ProtoReflect() protoreflect.Message
func (*BatchCheckHasActDoResponse_Item) Reset ¶
func (x *BatchCheckHasActDoResponse_Item) Reset()
func (*BatchCheckHasActDoResponse_Item) String ¶
func (x *BatchCheckHasActDoResponse_Item) String() string
type BatchCheckHasActDoResponse_ItemList ¶
type BatchCheckHasActDoResponse_ItemList struct {
List []*BatchCheckHasActDoResponse_Item `protobuf:"bytes,1,rep,name=list,proto3" json:"list,omitempty"`
// contains filtered or unexported fields
}
func (*BatchCheckHasActDoResponse_ItemList) Descriptor
deprecated
func (*BatchCheckHasActDoResponse_ItemList) Descriptor() ([]byte, []int)
Deprecated: Use BatchCheckHasActDoResponse_ItemList.ProtoReflect.Descriptor instead.
func (*BatchCheckHasActDoResponse_ItemList) GetList ¶
func (x *BatchCheckHasActDoResponse_ItemList) GetList() []*BatchCheckHasActDoResponse_Item
func (*BatchCheckHasActDoResponse_ItemList) ProtoMessage ¶
func (*BatchCheckHasActDoResponse_ItemList) ProtoMessage()
func (*BatchCheckHasActDoResponse_ItemList) ProtoReflect ¶
func (x *BatchCheckHasActDoResponse_ItemList) ProtoReflect() protoreflect.Message
func (*BatchCheckHasActDoResponse_ItemList) Reset ¶
func (x *BatchCheckHasActDoResponse_ItemList) Reset()
func (*BatchCheckHasActDoResponse_ItemList) String ¶
func (x *BatchCheckHasActDoResponse_ItemList) String() string
type BatchGetRecordRequest ¶
type BatchGetRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Params map[int64]*ObjectList `` /* 154-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BatchGetRecordRequest) Descriptor
deprecated
func (*BatchGetRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use BatchGetRecordRequest.ProtoReflect.Descriptor instead.
func (*BatchGetRecordRequest) GetBizCode ¶
func (x *BatchGetRecordRequest) GetBizCode() int32
func (*BatchGetRecordRequest) GetParams ¶
func (x *BatchGetRecordRequest) GetParams() map[int64]*ObjectList
func (*BatchGetRecordRequest) ProtoMessage ¶
func (*BatchGetRecordRequest) ProtoMessage()
func (*BatchGetRecordRequest) ProtoReflect ¶
func (x *BatchGetRecordRequest) ProtoReflect() protoreflect.Message
func (*BatchGetRecordRequest) Reset ¶
func (x *BatchGetRecordRequest) Reset()
func (*BatchGetRecordRequest) String ¶
func (x *BatchGetRecordRequest) String() string
type BatchGetRecordResponse ¶
type BatchGetRecordResponse struct {
Results map[int64]*RecordList `` /* 156-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BatchGetRecordResponse) Descriptor
deprecated
func (*BatchGetRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use BatchGetRecordResponse.ProtoReflect.Descriptor instead.
func (*BatchGetRecordResponse) GetResults ¶
func (x *BatchGetRecordResponse) GetResults() map[int64]*RecordList
func (*BatchGetRecordResponse) ProtoMessage ¶
func (*BatchGetRecordResponse) ProtoMessage()
func (*BatchGetRecordResponse) ProtoReflect ¶
func (x *BatchGetRecordResponse) ProtoReflect() protoreflect.Message
func (*BatchGetRecordResponse) Reset ¶
func (x *BatchGetRecordResponse) Reset()
func (*BatchGetRecordResponse) String ¶
func (x *BatchGetRecordResponse) String() string
type BatchGetSummaryRequest ¶
type BatchGetSummaryRequest struct {
Requests []*GetSummaryRequest `protobuf:"bytes,1,rep,name=requests,proto3" json:"requests,omitempty"`
// contains filtered or unexported fields
}
func (*BatchGetSummaryRequest) Descriptor
deprecated
func (*BatchGetSummaryRequest) Descriptor() ([]byte, []int)
Deprecated: Use BatchGetSummaryRequest.ProtoReflect.Descriptor instead.
func (*BatchGetSummaryRequest) GetRequests ¶
func (x *BatchGetSummaryRequest) GetRequests() []*GetSummaryRequest
func (*BatchGetSummaryRequest) ProtoMessage ¶
func (*BatchGetSummaryRequest) ProtoMessage()
func (*BatchGetSummaryRequest) ProtoReflect ¶
func (x *BatchGetSummaryRequest) ProtoReflect() protoreflect.Message
func (*BatchGetSummaryRequest) Reset ¶
func (x *BatchGetSummaryRequest) Reset()
func (*BatchGetSummaryRequest) String ¶
func (x *BatchGetSummaryRequest) String() string
type BatchGetSummaryResponse ¶
type BatchGetSummaryResponse struct {
Responses []*GetSummaryResponse `protobuf:"bytes,1,rep,name=responses,proto3" json:"responses,omitempty"`
// contains filtered or unexported fields
}
func (*BatchGetSummaryResponse) Descriptor
deprecated
func (*BatchGetSummaryResponse) Descriptor() ([]byte, []int)
Deprecated: Use BatchGetSummaryResponse.ProtoReflect.Descriptor instead.
func (*BatchGetSummaryResponse) GetResponses ¶
func (x *BatchGetSummaryResponse) GetResponses() []*GetSummaryResponse
func (*BatchGetSummaryResponse) ProtoMessage ¶
func (*BatchGetSummaryResponse) ProtoMessage()
func (*BatchGetSummaryResponse) ProtoReflect ¶
func (x *BatchGetSummaryResponse) ProtoReflect() protoreflect.Message
func (*BatchGetSummaryResponse) Reset ¶
func (x *BatchGetSummaryResponse) Reset()
func (*BatchGetSummaryResponse) String ¶
func (x *BatchGetSummaryResponse) String() string
type CancelRecordRequest ¶
type CancelRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*CancelRecordRequest) Descriptor
deprecated
func (*CancelRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use CancelRecordRequest.ProtoReflect.Descriptor instead.
func (*CancelRecordRequest) GetBizCode ¶
func (x *CancelRecordRequest) GetBizCode() int32
func (*CancelRecordRequest) GetOid ¶
func (x *CancelRecordRequest) GetOid() int64
func (*CancelRecordRequest) GetUid ¶
func (x *CancelRecordRequest) GetUid() int64
func (*CancelRecordRequest) ProtoMessage ¶
func (*CancelRecordRequest) ProtoMessage()
func (*CancelRecordRequest) ProtoReflect ¶
func (x *CancelRecordRequest) ProtoReflect() protoreflect.Message
func (*CancelRecordRequest) Reset ¶
func (x *CancelRecordRequest) Reset()
func (*CancelRecordRequest) String ¶
func (x *CancelRecordRequest) String() string
type CancelRecordResponse ¶
type CancelRecordResponse struct {
// contains filtered or unexported fields
}
func (*CancelRecordResponse) Descriptor
deprecated
func (*CancelRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use CancelRecordResponse.ProtoReflect.Descriptor instead.
func (*CancelRecordResponse) ProtoMessage ¶
func (*CancelRecordResponse) ProtoMessage()
func (*CancelRecordResponse) ProtoReflect ¶
func (x *CancelRecordResponse) ProtoReflect() protoreflect.Message
func (*CancelRecordResponse) Reset ¶
func (x *CancelRecordResponse) Reset()
func (*CancelRecordResponse) String ¶
func (x *CancelRecordResponse) String() string
type CheckHasActDoRequest ¶
type CheckHasActDoRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*CheckHasActDoRequest) Descriptor
deprecated
func (*CheckHasActDoRequest) Descriptor() ([]byte, []int)
Deprecated: Use CheckHasActDoRequest.ProtoReflect.Descriptor instead.
func (*CheckHasActDoRequest) GetBizCode ¶
func (x *CheckHasActDoRequest) GetBizCode() int32
func (*CheckHasActDoRequest) GetOid ¶
func (x *CheckHasActDoRequest) GetOid() int64
func (*CheckHasActDoRequest) GetUid ¶
func (x *CheckHasActDoRequest) GetUid() int64
func (*CheckHasActDoRequest) ProtoMessage ¶
func (*CheckHasActDoRequest) ProtoMessage()
func (*CheckHasActDoRequest) ProtoReflect ¶
func (x *CheckHasActDoRequest) ProtoReflect() protoreflect.Message
func (*CheckHasActDoRequest) Reset ¶
func (x *CheckHasActDoRequest) Reset()
func (*CheckHasActDoRequest) String ¶
func (x *CheckHasActDoRequest) String() string
type CheckHasActDoResponse ¶
type CheckHasActDoResponse struct {
Do bool `protobuf:"varint,1,opt,name=do,proto3" json:"do,omitempty"`
// contains filtered or unexported fields
}
func (*CheckHasActDoResponse) Descriptor
deprecated
func (*CheckHasActDoResponse) Descriptor() ([]byte, []int)
Deprecated: Use CheckHasActDoResponse.ProtoReflect.Descriptor instead.
func (*CheckHasActDoResponse) GetDo ¶
func (x *CheckHasActDoResponse) GetDo() bool
func (*CheckHasActDoResponse) ProtoMessage ¶
func (*CheckHasActDoResponse) ProtoMessage()
func (*CheckHasActDoResponse) ProtoReflect ¶
func (x *CheckHasActDoResponse) ProtoReflect() protoreflect.Message
func (*CheckHasActDoResponse) Reset ¶
func (x *CheckHasActDoResponse) Reset()
func (*CheckHasActDoResponse) String ¶
func (x *CheckHasActDoResponse) String() string
type CounterServiceClient ¶
type CounterServiceClient interface {
// 添加一条计数记录
AddRecord(ctx context.Context, in *AddRecordRequest, opts ...grpc.CallOption) (*AddRecordResponse, error)
// 取消计数记录
CancelRecord(ctx context.Context, in *CancelRecordRequest, opts ...grpc.CallOption) (*CancelRecordResponse, error)
// 获取一条计数记录
GetRecord(ctx context.Context, in *GetRecordRequest, opts ...grpc.CallOption) (*GetRecordResponse, error)
// 批量获取计数记录
BatchGetRecord(ctx context.Context, in *BatchGetRecordRequest, opts ...grpc.CallOption) (*BatchGetRecordResponse, error)
// 获取oid计数总数
GetSummary(ctx context.Context, in *GetSummaryRequest, opts ...grpc.CallOption) (*GetSummaryResponse, error)
// 批量获取oid计数总数
BatchGetSummary(ctx context.Context, in *BatchGetSummaryRequest, opts ...grpc.CallOption) (*BatchGetSummaryResponse, error)
// 分页获取用户的计数(ActDo)记录
PageGetUserRecord(ctx context.Context, in *PageGetUserRecordRequest, opts ...grpc.CallOption) (*PageGetUserRecordResponse, error)
// 获取一条(ActDo)计数记录
CheckHasActDo(ctx context.Context, in *CheckHasActDoRequest, opts ...grpc.CallOption) (*CheckHasActDoResponse, error)
// 批量获取(ActDo)计数记录
BatchCheckHasActDo(ctx context.Context, in *BatchCheckHasActDoDoRequest, opts ...grpc.CallOption) (*BatchCheckHasActDoResponse, error)
}
CounterServiceClient is the client API for CounterService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCounterServiceClient ¶
func NewCounterServiceClient(cc grpc.ClientConnInterface) CounterServiceClient
type CounterServiceServer ¶
type CounterServiceServer interface {
// 添加一条计数记录
AddRecord(context.Context, *AddRecordRequest) (*AddRecordResponse, error)
// 取消计数记录
CancelRecord(context.Context, *CancelRecordRequest) (*CancelRecordResponse, error)
// 获取一条计数记录
GetRecord(context.Context, *GetRecordRequest) (*GetRecordResponse, error)
// 批量获取计数记录
BatchGetRecord(context.Context, *BatchGetRecordRequest) (*BatchGetRecordResponse, error)
// 获取oid计数总数
GetSummary(context.Context, *GetSummaryRequest) (*GetSummaryResponse, error)
// 批量获取oid计数总数
BatchGetSummary(context.Context, *BatchGetSummaryRequest) (*BatchGetSummaryResponse, error)
// 分页获取用户的计数(ActDo)记录
PageGetUserRecord(context.Context, *PageGetUserRecordRequest) (*PageGetUserRecordResponse, error)
// 获取一条(ActDo)计数记录
CheckHasActDo(context.Context, *CheckHasActDoRequest) (*CheckHasActDoResponse, error)
// 批量获取(ActDo)计数记录
BatchCheckHasActDo(context.Context, *BatchCheckHasActDoDoRequest) (*BatchCheckHasActDoResponse, error)
// contains filtered or unexported methods
}
CounterServiceServer is the server API for CounterService service. All implementations must embed UnimplementedCounterServiceServer for forward compatibility.
type DelRecordRequest ¶
type DelRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*DelRecordRequest) Descriptor
deprecated
func (*DelRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use DelRecordRequest.ProtoReflect.Descriptor instead.
func (*DelRecordRequest) GetBizCode ¶
func (x *DelRecordRequest) GetBizCode() int32
func (*DelRecordRequest) GetOid ¶
func (x *DelRecordRequest) GetOid() int64
func (*DelRecordRequest) GetUid ¶
func (x *DelRecordRequest) GetUid() int64
func (*DelRecordRequest) ProtoMessage ¶
func (*DelRecordRequest) ProtoMessage()
func (*DelRecordRequest) ProtoReflect ¶
func (x *DelRecordRequest) ProtoReflect() protoreflect.Message
func (*DelRecordRequest) Reset ¶
func (x *DelRecordRequest) Reset()
func (*DelRecordRequest) String ¶
func (x *DelRecordRequest) String() string
type DelRecordResponse ¶
type DelRecordResponse struct {
// contains filtered or unexported fields
}
func (*DelRecordResponse) Descriptor
deprecated
func (*DelRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use DelRecordResponse.ProtoReflect.Descriptor instead.
func (*DelRecordResponse) ProtoMessage ¶
func (*DelRecordResponse) ProtoMessage()
func (*DelRecordResponse) ProtoReflect ¶
func (x *DelRecordResponse) ProtoReflect() protoreflect.Message
func (*DelRecordResponse) Reset ¶
func (x *DelRecordResponse) Reset()
func (*DelRecordResponse) String ¶
func (x *DelRecordResponse) String() string
type GetRecordRequest ¶
type GetRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*GetRecordRequest) Descriptor
deprecated
func (*GetRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRecordRequest.ProtoReflect.Descriptor instead.
func (*GetRecordRequest) GetBizCode ¶
func (x *GetRecordRequest) GetBizCode() int32
func (*GetRecordRequest) GetOid ¶
func (x *GetRecordRequest) GetOid() int64
func (*GetRecordRequest) GetUid ¶
func (x *GetRecordRequest) GetUid() int64
func (*GetRecordRequest) ProtoMessage ¶
func (*GetRecordRequest) ProtoMessage()
func (*GetRecordRequest) ProtoReflect ¶
func (x *GetRecordRequest) ProtoReflect() protoreflect.Message
func (*GetRecordRequest) Reset ¶
func (x *GetRecordRequest) Reset()
func (*GetRecordRequest) String ¶
func (x *GetRecordRequest) String() string
type GetRecordResponse ¶
type GetRecordResponse struct {
Record *Record `protobuf:"bytes,1,opt,name=record,proto3" json:"record,omitempty"`
// contains filtered or unexported fields
}
func (*GetRecordResponse) Descriptor
deprecated
func (*GetRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetRecordResponse.ProtoReflect.Descriptor instead.
func (*GetRecordResponse) GetRecord ¶
func (x *GetRecordResponse) GetRecord() *Record
func (*GetRecordResponse) ProtoMessage ¶
func (*GetRecordResponse) ProtoMessage()
func (*GetRecordResponse) ProtoReflect ¶
func (x *GetRecordResponse) ProtoReflect() protoreflect.Message
func (*GetRecordResponse) Reset ¶
func (x *GetRecordResponse) Reset()
func (*GetRecordResponse) String ¶
func (x *GetRecordResponse) String() string
type GetSummaryRequest ¶
type GetSummaryRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Oid int64 `protobuf:"varint,2,opt,name=oid,proto3" json:"oid,omitempty"`
// contains filtered or unexported fields
}
func (*GetSummaryRequest) Descriptor
deprecated
func (*GetSummaryRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSummaryRequest.ProtoReflect.Descriptor instead.
func (*GetSummaryRequest) GetBizCode ¶
func (x *GetSummaryRequest) GetBizCode() int32
func (*GetSummaryRequest) GetOid ¶
func (x *GetSummaryRequest) GetOid() int64
func (*GetSummaryRequest) ProtoMessage ¶
func (*GetSummaryRequest) ProtoMessage()
func (*GetSummaryRequest) ProtoReflect ¶
func (x *GetSummaryRequest) ProtoReflect() protoreflect.Message
func (*GetSummaryRequest) Reset ¶
func (x *GetSummaryRequest) Reset()
func (*GetSummaryRequest) String ¶
func (x *GetSummaryRequest) String() string
type GetSummaryResponse ¶
type GetSummaryResponse struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Oid int64 `protobuf:"varint,2,opt,name=oid,proto3" json:"oid,omitempty"`
Count int64 `protobuf:"varint,3,opt,name=count,proto3" json:"count,omitempty"`
// contains filtered or unexported fields
}
func (*GetSummaryResponse) Descriptor
deprecated
func (*GetSummaryResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetSummaryResponse.ProtoReflect.Descriptor instead.
func (*GetSummaryResponse) GetBizCode ¶
func (x *GetSummaryResponse) GetBizCode() int32
func (*GetSummaryResponse) GetCount ¶
func (x *GetSummaryResponse) GetCount() int64
func (*GetSummaryResponse) GetOid ¶
func (x *GetSummaryResponse) GetOid() int64
func (*GetSummaryResponse) ProtoMessage ¶
func (*GetSummaryResponse) ProtoMessage()
func (*GetSummaryResponse) ProtoReflect ¶
func (x *GetSummaryResponse) ProtoReflect() protoreflect.Message
func (*GetSummaryResponse) Reset ¶
func (x *GetSummaryResponse) Reset()
func (*GetSummaryResponse) String ¶
func (x *GetSummaryResponse) String() string
type ObjectList ¶
type ObjectList struct {
Oids []int64 `protobuf:"varint,1,rep,packed,name=oids,proto3" json:"oids,omitempty"`
// contains filtered or unexported fields
}
func (*ObjectList) Descriptor
deprecated
func (*ObjectList) Descriptor() ([]byte, []int)
Deprecated: Use ObjectList.ProtoReflect.Descriptor instead.
func (*ObjectList) GetOids ¶
func (x *ObjectList) GetOids() []int64
func (*ObjectList) ProtoMessage ¶
func (*ObjectList) ProtoMessage()
func (*ObjectList) ProtoReflect ¶
func (x *ObjectList) ProtoReflect() protoreflect.Message
func (*ObjectList) Reset ¶
func (x *ObjectList) Reset()
func (*ObjectList) String ¶
func (x *ObjectList) String() string
type PageGetUserRecordRequest ¶
type PageGetUserRecordRequest struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Cursor string `protobuf:"bytes,3,opt,name=cursor,proto3" json:"cursor,omitempty"`
Count int32 `protobuf:"varint,4,opt,name=count,proto3" json:"count,omitempty"`
SortRule SortRule `protobuf:"varint,5,opt,name=sort_rule,json=sortRule,proto3,enum=counter.api.v1.SortRule" json:"sort_rule,omitempty"`
// contains filtered or unexported fields
}
func (*PageGetUserRecordRequest) Descriptor
deprecated
func (*PageGetUserRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use PageGetUserRecordRequest.ProtoReflect.Descriptor instead.
func (*PageGetUserRecordRequest) GetBizCode ¶
func (x *PageGetUserRecordRequest) GetBizCode() int32
func (*PageGetUserRecordRequest) GetCount ¶
func (x *PageGetUserRecordRequest) GetCount() int32
func (*PageGetUserRecordRequest) GetCursor ¶
func (x *PageGetUserRecordRequest) GetCursor() string
func (*PageGetUserRecordRequest) GetSortRule ¶
func (x *PageGetUserRecordRequest) GetSortRule() SortRule
func (*PageGetUserRecordRequest) GetUid ¶
func (x *PageGetUserRecordRequest) GetUid() int64
func (*PageGetUserRecordRequest) ProtoMessage ¶
func (*PageGetUserRecordRequest) ProtoMessage()
func (*PageGetUserRecordRequest) ProtoReflect ¶
func (x *PageGetUserRecordRequest) ProtoReflect() protoreflect.Message
func (*PageGetUserRecordRequest) Reset ¶
func (x *PageGetUserRecordRequest) Reset()
func (*PageGetUserRecordRequest) String ¶
func (x *PageGetUserRecordRequest) String() string
type PageGetUserRecordResponse ¶
type PageGetUserRecordResponse struct {
NextCursor string `protobuf:"bytes,1,opt,name=next_cursor,json=nextCursor,proto3" json:"next_cursor,omitempty"`
HasNext bool `protobuf:"varint,2,opt,name=has_next,json=hasNext,proto3" json:"has_next,omitempty"`
Items []*Record `protobuf:"bytes,3,rep,name=items,proto3" json:"items,omitempty"`
// contains filtered or unexported fields
}
func (*PageGetUserRecordResponse) Descriptor
deprecated
func (*PageGetUserRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use PageGetUserRecordResponse.ProtoReflect.Descriptor instead.
func (*PageGetUserRecordResponse) GetHasNext ¶
func (x *PageGetUserRecordResponse) GetHasNext() bool
func (*PageGetUserRecordResponse) GetItems ¶
func (x *PageGetUserRecordResponse) GetItems() []*Record
func (*PageGetUserRecordResponse) GetNextCursor ¶
func (x *PageGetUserRecordResponse) GetNextCursor() string
func (*PageGetUserRecordResponse) ProtoMessage ¶
func (*PageGetUserRecordResponse) ProtoMessage()
func (*PageGetUserRecordResponse) ProtoReflect ¶
func (x *PageGetUserRecordResponse) ProtoReflect() protoreflect.Message
func (*PageGetUserRecordResponse) Reset ¶
func (x *PageGetUserRecordResponse) Reset()
func (*PageGetUserRecordResponse) String ¶
func (x *PageGetUserRecordResponse) String() string
type Record ¶
type Record struct {
BizCode int32 `protobuf:"varint,1,opt,name=biz_code,json=bizCode,proto3" json:"biz_code,omitempty"`
Uid int64 `protobuf:"varint,2,opt,name=uid,proto3" json:"uid,omitempty"`
Oid int64 `protobuf:"varint,3,opt,name=oid,proto3" json:"oid,omitempty"`
Act RecordAct `protobuf:"varint,4,opt,name=act,proto3,enum=counter.api.v1.RecordAct" json:"act,omitempty"`
Ctime int64 `protobuf:"varint,5,opt,name=ctime,proto3" json:"ctime,omitempty"`
Mtime int64 `protobuf:"varint,6,opt,name=mtime,proto3" json:"mtime,omitempty"`
// contains filtered or unexported fields
}
func (*Record) Descriptor
deprecated
func (*Record) GetBizCode ¶
func (*Record) ProtoMessage ¶
func (*Record) ProtoMessage()
func (*Record) ProtoReflect ¶
func (x *Record) ProtoReflect() protoreflect.Message
type RecordAct ¶
type RecordAct int32
func (RecordAct) Descriptor ¶
func (RecordAct) Descriptor() protoreflect.EnumDescriptor
func (RecordAct) EnumDescriptor
deprecated
func (RecordAct) Number ¶
func (x RecordAct) Number() protoreflect.EnumNumber
func (RecordAct) Type ¶
func (RecordAct) Type() protoreflect.EnumType
type RecordList ¶
type RecordList struct {
List []*Record `protobuf:"bytes,1,rep,name=list,proto3" json:"list,omitempty"`
// contains filtered or unexported fields
}
func (*RecordList) Descriptor
deprecated
func (*RecordList) Descriptor() ([]byte, []int)
Deprecated: Use RecordList.ProtoReflect.Descriptor instead.
func (*RecordList) GetList ¶
func (x *RecordList) GetList() []*Record
func (*RecordList) ProtoMessage ¶
func (*RecordList) ProtoMessage()
func (*RecordList) ProtoReflect ¶
func (x *RecordList) ProtoReflect() protoreflect.Message
func (*RecordList) Reset ¶
func (x *RecordList) Reset()
func (*RecordList) String ¶
func (x *RecordList) String() string
type SortRule ¶
type SortRule int32
func (SortRule) Descriptor ¶
func (SortRule) Descriptor() protoreflect.EnumDescriptor
func (SortRule) EnumDescriptor
deprecated
func (SortRule) Number ¶
func (x SortRule) Number() protoreflect.EnumNumber
func (SortRule) Type ¶
func (SortRule) Type() protoreflect.EnumType
type UnimplementedCounterServiceServer ¶
type UnimplementedCounterServiceServer struct{}
UnimplementedCounterServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCounterServiceServer) AddRecord ¶
func (UnimplementedCounterServiceServer) AddRecord(context.Context, *AddRecordRequest) (*AddRecordResponse, error)
func (UnimplementedCounterServiceServer) BatchCheckHasActDo ¶
func (UnimplementedCounterServiceServer) BatchCheckHasActDo(context.Context, *BatchCheckHasActDoDoRequest) (*BatchCheckHasActDoResponse, error)
func (UnimplementedCounterServiceServer) BatchGetRecord ¶
func (UnimplementedCounterServiceServer) BatchGetRecord(context.Context, *BatchGetRecordRequest) (*BatchGetRecordResponse, error)
func (UnimplementedCounterServiceServer) BatchGetSummary ¶
func (UnimplementedCounterServiceServer) BatchGetSummary(context.Context, *BatchGetSummaryRequest) (*BatchGetSummaryResponse, error)
func (UnimplementedCounterServiceServer) CancelRecord ¶
func (UnimplementedCounterServiceServer) CancelRecord(context.Context, *CancelRecordRequest) (*CancelRecordResponse, error)
func (UnimplementedCounterServiceServer) CheckHasActDo ¶
func (UnimplementedCounterServiceServer) CheckHasActDo(context.Context, *CheckHasActDoRequest) (*CheckHasActDoResponse, error)
func (UnimplementedCounterServiceServer) GetRecord ¶
func (UnimplementedCounterServiceServer) GetRecord(context.Context, *GetRecordRequest) (*GetRecordResponse, error)
func (UnimplementedCounterServiceServer) GetSummary ¶
func (UnimplementedCounterServiceServer) GetSummary(context.Context, *GetSummaryRequest) (*GetSummaryResponse, error)
func (UnimplementedCounterServiceServer) PageGetUserRecord ¶
func (UnimplementedCounterServiceServer) PageGetUserRecord(context.Context, *PageGetUserRecordRequest) (*PageGetUserRecordResponse, error)
type UnsafeCounterServiceServer ¶
type UnsafeCounterServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCounterServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CounterServiceServer will result in compilation errors.